mcconnell 2003/10/14 03:52:06
Modified: merlin/platform/tutorials/hello project.xml
merlin/platform/tutorials/hello/conf block.xml
merlin/platform/tutorials/hello/src/test/tutorial
StandardTestCase.java
Log:
Update to latest rev of test case.
Revision Changes Path
1.3 +1 -1 avalon/merlin/platform/tutorials/hello/project.xml
Index: project.xml
===================================================================
RCS file: /home/cvs/avalon/merlin/platform/tutorials/hello/project.xml,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- project.xml 13 Oct 2003 14:13:17 -0000 1.2
+++ project.xml 14 Oct 2003 10:52:05 -0000 1.3
@@ -27,7 +27,7 @@
<dependency>
<groupId>merlin</groupId>
<artifactId>merlin-unit</artifactId>
- <version>3.1-SNAPSHOT</version>
+ <version>3.1-dev</version>
</dependency>
</dependencies>
1.2 +0 -8 avalon/merlin/platform/tutorials/hello/conf/block.xml
Index: block.xml
===================================================================
RCS file: /home/cvs/avalon/merlin/platform/tutorials/hello/conf/block.xml,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- block.xml 24 Sep 2003 09:34:01 -0000 1.1
+++ block.xml 14 Oct 2003 10:52:05 -0000 1.2
@@ -1,14 +1,6 @@
<container name="tutorial">
- <classloader>
- <classpath>
- <repository>
- <resource id="avalon-framework:avalon-framework-impl" version="4.1.5"/>
- </repository>
- </classpath>
- </classloader>
-
<component name="hello" class="tutorial.HelloComponent"/>
</container>
1.2 +2 -3
avalon/merlin/platform/tutorials/hello/src/test/tutorial/StandardTestCase.java
Index: StandardTestCase.java
===================================================================
RCS file:
/home/cvs/avalon/merlin/platform/tutorials/hello/src/test/tutorial/StandardTestCase.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- StandardTestCase.java 13 Oct 2003 14:13:17 -0000 1.1
+++ StandardTestCase.java 14 Oct 2003 10:52:05 -0000 1.2
@@ -49,12 +49,10 @@
package tutorial;
-import java.net.URL;
-
import org.apache.avalon.merlin.unit.AbstractMerlinTestCase;
/**
* Abstract Merlin Test Case.
*
* @author [EMAIL PROTECTED]
*/
@@ -86,6 +84,7 @@
public void testServiceResolution() throws Exception
{
Object hello = resolve( "hello" );
+ assertTrue( hello != null );
getLogger().info( "Hello established." );
}
}
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -49,12 +49,10 @@
import org.apache.avalon.merlin.unit.AbstractMerlinTestCase;
/**
- * Abstract Merlin Test Case.
+ * Hello Test Case.
*
* @author [EMAIL PROTECTED]